@@ -32,10 +32,7 @@ class IDrone(IRobot, abc.ABC):
         """
         e_devices = {}
         for device, name, *sampling_period in en_devices:
-            if len(sampling_period) == 0:
-                time_step = self.basic_time_step
-            else:
-                time_step = sampling_period[0]
+            time_step = self.basic_time_step if len(sampling_period) == 0 else sampling_period[0]
 
             if EnableableDevice(device) == EnableableDevice.KEYBOARD:
                 e_devices['keyboard'] = {'type': device, 'device': self.keyboard}
