@@ -1,5 +1,6 @@
 import abc
 
+from controller import Radar, RadarTarget
 from flockai.interfaces.drone import IDrone
 
 
@@ -67,20 +68,30 @@ class AutopilotControlledDrone(IDrone, abc.ABC):
         In case we are on the target no input is given
         :return:
         """
-        self.simulation_step += 1
-        if self.simulation_step % 5 == 0:
-            if self.target_has_reached():
-                return 0, 0, 0
-
-            if self.on_track():
-                self.simulation_step -= 1
-                return 0, 4, 0
-
-            return 0, 0, 2.3
-        return 0, 0, 0
-        # # Transform the keyboard input to disturbances on the stabilization algorithm.
-        # roll_disturbance = 0
-        # pitch_disturbance = 2
-        # yaw_disturbance = 0
+        # self.simulation_step += 1
+        # if self.simulation_step % 5 == 0:
+        #     if self.target_has_reached():
+        #         return 0, 0, 0
         #
-        # return roll_disturbance, pitch_disturbance, yaw_disturbance
+        #     if self.on_track():
+        #         self.simulation_step -= 1
+        #         return 0, 4, 0
+        #
+        #     return 0, 0, 2.3
+        # return 0, 0, 0
+        print("\033c", end="")
+
+        radar: Radar = self.devices['radar']['device']
+        total_targets = radar.getNumberOfTargets()
+        targets = radar.getTargets()
+
+        print('Currently seeing', total_targets, 'targets')
+        for i in range(total_targets):
+            print(f'--target {i}: distance = {targets[i].distance} azimuth = {targets[i].azimuth}')
+
+        # # Transform the keyboard input to disturbances on the stabilization algorithm.
+        roll_disturbance = 0
+        pitch_disturbance = 0
+        yaw_disturbance = 0
+
+        return roll_disturbance, pitch_disturbance, yaw_disturbance
