@@ -11,8 +11,7 @@ class HumiditySensor(ISensor):
 
     def get_values(self):
         data = self._get_data()
-        humidity = float(data[0])
-        print(humidity)
+        humidity = float(data)
         self.entries += 1
         self.cum_sum += humidity
         humidity_avg = self.cum_sum / self.entries
